@@ -197,17 +197,23 @@ bool Value::operator!=(const Value& src) const
 
 
 Value::Value()
+:
+  Glib::ValueBase()
 {
   //Creates a null. TODO: Is this really equivalent to gda_value_new_null()?
 }
 
 Value::Value(const Value& src)
+:
+  Glib::ValueBase()
 {
   if(G_IS_VALUE(src.gobj()))
     init(src.gobj());
 }
 
 Value::Value(const GValue* castitem)
+:
+  Glib::ValueBase()
 {
   if(G_IS_VALUE(castitem))
     init(castitem);
@@ -410,6 +416,16 @@ void Value::set(gushort val)
   gda_value_set_ushort(gobj(), val); 
 }
 
+glong Value::get_long() const
+{
+  return g_value_get_long(const_cast<GValue*>(gobj()));
+}
+
+void Value::set(glong val)
+{
+  g_value_set_long(gobj(), val); 
+}
+
 gulong Value::get_ulong() const
 {
   return g_value_get_ulong(const_cast<GValue*>(gobj()));
@@ -433,6 +449,7 @@ void Value::set(const Glib::ustring& val)
 
 void Value::set(const char* val)
 {
+  value_reinit(gobj(), G_TYPE_STRING);
   g_value_set_string(gobj(), val);
 }
 
